@@ -71,7 +71,7 @@ sub begin_session {
 	}
 	$tarball = abs_path($chroot);
     } else {
-	my $xdg_cache_home = $ENV{'HOME'} . "/.cache/sbuild";
+	my $xdg_cache_home = $self->get_conf('HOME') . "/.cache/sbuild";
 	if (defined($ENV{'XDG_CACHE_HOME'})) {
 	    $xdg_cache_home = $ENV{'XDG_CACHE_HOME'} . '/sbuild';
 	}
@@ -105,9 +105,16 @@ sub begin_session {
     my @idmap = read_subuid_subgid;
 
     # sanity check
-    if (scalar(@idmap) != 2 || $idmap[0][0] ne 'u' || $idmap[1][0] ne 'g') {
-	printf STDERR "invalid idmap\n";
-	return 0;
+    if (   scalar(@idmap) != 2
+        || $idmap[0][0] ne 'u'
+        || $idmap[1][0] ne 'g'
+        || length $idmap[0][1] == 0
+        || length $idmap[0][2] == 0
+        || length $idmap[1][1] == 0
+        || length $idmap[1][2] == 0)
+    {
+        printf STDERR "invalid idmap\n";
+        return 0;
     }
 
     $self->set('Uid Gid Map', \@idmap);
@@ -264,17 +271,23 @@ sub _get_exec_argv {
     my $dir = shift;
     my $user = shift;
     my $disable_network = shift // 0;
+    my $build_inside_init = shift // 0;
 
     # On systems with libnss-resolve installed there is no need for a
     # /etc/resolv.conf. This works around this by adding 127.0.0.53 (default
     # for systemd-resolved) in that case.
     my $network_setup = '[ -f /etc/resolv.conf ] && cat /etc/resolv.conf > "$rootdir/etc/resolv.conf" || echo "nameserver 127.0.0.53" > "$rootdir/etc/resolv.conf";';
     my $unshare = CLONE_NEWNS | CLONE_NEWPID | CLONE_NEWUTS | CLONE_NEWIPC;
+    my $init = "";
     if ($disable_network) {
 	$unshare |= CLONE_NEWNET;
 	$network_setup = 'ip link set lo up;> "$rootdir/etc/resolv.conf";';
     }
 
+    if ($build_inside_init) {
+	$init = "/usr/bin/dumb-init";
+    }
+
     my @bind_mounts = ();
     for my $entry (@{$self->get_conf('UNSHARE_BIND_MOUNTS')}) {
 	push @bind_mounts, $entry->{directory}, $entry->{mountpoint};
@@ -314,7 +327,7 @@ sub _get_exec_argv {
 	mount -o rbind /sys \"\$rootdir/sys\";
 	mkdir -p \"\$rootdir/proc\";
 	mount -t proc proc \"\$rootdir/proc\";
-	exec /usr/sbin/chroot \"\$rootdir\" /sbin/runuser -u \"\$user\" -- sh -c \"cd \\\"\\\$1\\\" && shift && \\\"\\\$@\\\"\" -- \"\$dir\" \"\$@\";
+	exec /usr/sbin/chroot \"\$rootdir\" $init /sbin/runuser -u \"\$user\" -- sh -c \"cd \\\"\\\$1\\\" && shift && \\\"\\\$@\\\"\" -- \"\$dir\" \"\$@\";
 	", '--', $self->get('Session ID'), $user, $dir, @bind_mounts, '--'
     );
 }
@@ -351,11 +364,16 @@ sub get_command_internal {
     }
 
     my $disable_network = 0;
-    if (defined($options->{'DISABLE_NETWORK'}) && $options->{'DISABLE_NETWORK'}) {
+    if (defined($options->{'ENABLE_NETWORK'}) && $options->{'ENABLE_NETWORK'} == 0) {
 	$disable_network = 1;
     }
 
-    my @cmdline = $self->_get_exec_argv($dir, $user, $disable_network);
+    my $build_inside_init = 0;
+    if (defined($options->{'BUILD_INSIDE_INIT'}) && $options->{'BUILD_INSIDE_INIT'}) {
+	$build_inside_init = 1;
+    }
+
+    my @cmdline = $self->_get_exec_argv($dir, $user, $disable_network, $build_inside_init);
     if (ref $command) {
 	push @cmdline, @$command;
     } else {
